@@ -10,9 +10,9 @@ from functools import update_wrapper
 from .wsgi import ClosingIterator
 
 if t.TYPE_CHECKING:
-    from wsgiref.types import StartResponse
-    from wsgiref.types import WSGIApplication
-    from wsgiref.types import WSGIEnvironment
+    from _typeshed.wsgi import StartResponse
+    from _typeshed.wsgi import WSGIApplication
+    from _typeshed.wsgi import WSGIEnvironment
 
 F = t.TypeVar("F", bound=t.Callable[..., t.Any])
 
@@ -54,13 +54,18 @@ try:
                 from gevent.monkey import is_object_patched
             except ImportError:
                 # Gevent isn't used, but Greenlet is and hasn't patched
-                raise _CannotUseContextVar()
+                raise _CannotUseContextVar() from None
             else:
                 if is_object_patched("threading", "local") and not is_object_patched(
                     "contextvars", "ContextVar"
                 ):
                     raise _CannotUseContextVar()
 
+    def __release_local__(storage: t.Any) -> None:
+        # Can remove when support for non-stdlib ContextVars is
+        # removed, see "Fake" version below.
+        storage.set({})
+
 
 except (ImportError, _CannotUseContextVar):
 
@@ -79,6 +84,11 @@ except (ImportError, _CannotUseContextVar):
         def set(self, value: t.Dict[str, t.Any]) -> None:
             self.storage[_get_ident()] = value
 
+    def __release_local__(storage: t.Any) -> None:
+        # Special version to ensure that the storage is cleaned up on
+        # release.
+        storage.storage.pop(_get_ident(), None)
+
 
 def release_local(local: t.Union["Local", "LocalStack"]) -> None:
     """Releases the contents of the local for the current context.
@@ -145,14 +155,14 @@ class Local:
         return LocalProxy(self, proxy)
 
     def __release_local__(self) -> None:
-        self._storage.set({})
+        __release_local__(self._storage)
 
     def __getattr__(self, name: str) -> t.Any:
         values = self._storage.get({})
         try:
             return values[name]
         except KeyError:
-            raise AttributeError(name)
+            raise AttributeError(name) from None
 
     def __setattr__(self, name: str, value: t.Any) -> None:
         values = self._storage.get({}).copy()
@@ -165,7 +175,7 @@ class Local:
             del values[name]
             self._storage.set(values)
         except KeyError:
-            raise AttributeError(name)
+            raise AttributeError(name) from None
 
 
 class LocalStack:
@@ -252,7 +262,7 @@ class LocalStack:
 class LocalManager:
     """Local objects cannot manage themselves. For that you need a local
     manager. You can pass a local manager multiple locals or add them
-    later y appending them to `manager.locals`. Every time the manager
+    later by appending them to `manager.locals`. Every time the manager
     cleans up, it will clean up all the data left in the locals for this
     context.
 
@@ -546,7 +556,8 @@ class LocalProxy:
         try:
             return getattr(self.__local, self.__name)  # type: ignore
         except AttributeError:
-            raise RuntimeError(f"no object bound to {self.__name}")  # type: ignore
+            name = self.__name  # type: ignore
+            raise RuntimeError(f"no object bound to {name}") from None
 
     __doc__ = _ProxyLookup(  # type: ignore
         class_value=__doc__, fallback=lambda self: type(self).__doc__
